@@ -5,12 +5,14 @@ from mito_ai.completions.models import AgentExecutionMetadata
 from mito_ai.completions.prompt_builders.prompt_constants import (
     FILES_SECTION_HEADING,
     JUPYTER_NOTEBOOK_SECTION_HEADING,
+    STREAMLIT_APP_STATUS_SECTION_HEADING,
     VARIABLES_SECTION_HEADING,
     cell_update_output_str
 )
 from mito_ai.completions.prompt_builders.utils import (
     get_rules_str,
     get_selected_context_str,
+    get_streamlit_app_status_str,
 )
 
 
@@ -20,7 +22,7 @@ def create_agent_execution_prompt(md: AgentExecutionMetadata) -> str:
     ai_optimized_cells_str = '\n'.join([f"{cell}" for cell in md.aiOptimizedCells or []])
     rules_str = get_rules_str(md.additionalContext)
     selected_context_str = get_selected_context_str(md.additionalContext)
-        
+    streamlit_status_str = get_streamlit_app_status_str(md.streamlitAppIsOpen)
     context_str = f"""Remember to choose the correct tool to respond with.
 
 {rules_str}
@@ -35,6 +37,9 @@ def create_agent_execution_prompt(md: AgentExecutionMetadata) -> str:
 {FILES_SECTION_HEADING}
 {files_str}
 
+{STREAMLIT_APP_STATUS_SECTION_HEADING}
+{streamlit_status_str}
+
 {selected_context_str}
 
 {cell_update_output_str(md.base64EncodedActiveCellOutput is not None)}"""
