@@ -5,7 +5,7 @@ from typing import Any, List, Tuple
 from jupyter_server.utils import url_path_join
 from mito_ai.log.handlers import LogHandler
 
-def get_log_urls(base_url: str) -> List[Tuple[str, Any, dict]]:
+def get_log_urls(base_url: str, key_type: str) -> List[Tuple[str, Any, dict]]:
     """Get all log related URL patterns.
 
     Args:
@@ -15,7 +15,7 @@ def get_log_urls(base_url: str) -> List[Tuple[str, Any, dict]]:
         List of (url_pattern, handler_class, handler_kwargs) tuples
     """
     BASE_URL = base_url + "/mito-ai"
-    
+        
     return [
-        (url_path_join(BASE_URL, "log"), LogHandler, {}),
+        (url_path_join(BASE_URL, "log"), LogHandler, {"key_type": key_type}),
     ]
\ No newline at end of file
