@@ -4,24 +4,18 @@
 import os
 from anthropic.types import MessageParam
 from typing import List, Optional, Tuple, cast
-from mito_ai.streamlit_conversion.agent_utils import apply_patch_to_text, extract_todo_placeholders, fix_diff_headers, get_response_from_agent
+from mito_ai.streamlit_conversion.agent_utils import extract_todo_placeholders, get_response_from_agent
 from mito_ai.streamlit_conversion.prompts.streamlit_app_creation_prompt import get_streamlit_app_creation_prompt
 from mito_ai.streamlit_conversion.prompts.streamlit_error_correction_prompt import get_streamlit_error_correction_prompt
 from mito_ai.streamlit_conversion.prompts.streamlit_finish_todo_prompt import get_finish_todo_prompt
 from mito_ai.streamlit_conversion.prompts.update_existing_app_prompt import get_update_existing_app_prompt
 from mito_ai.streamlit_conversion.validate_streamlit_app import validate_app
-from mito_ai.streamlit_conversion.streamlit_utils import extract_code_blocks, create_app_file, extract_unified_diff_blocks, get_app_code_from_file, parse_jupyter_notebook_to_extract_required_content
+from mito_ai.streamlit_conversion.streamlit_utils import extract_code_blocks, create_app_file, get_app_code_from_file, parse_jupyter_notebook_to_extract_required_content
+from mito_ai.streamlit_conversion.search_replace_utils import extract_search_replace_blocks, apply_search_replace
 from mito_ai.completions.models import MessageType
-from mito_ai.utils.telemetry_utils import log_streamlit_app_creation_error, log_streamlit_app_creation_retry, log_streamlit_app_creation_success
-from mito_ai.streamlit_conversion.streamlit_utils import clean_directory_check
-
-def get_app_directory(notebook_path: str) -> str:
-    # Make sure the path is absolute if it is not already
-    absolute_notebook_path = os.path.abspath(notebook_path)
-    
-    # Get the directory of the notebook
-    app_directory = os.path.dirname(absolute_notebook_path)
-    return app_directory
+from mito_ai.utils.error_classes import StreamlitConversionError
+from mito_ai.utils.telemetry_utils import log_streamlit_app_validation_retry, log_streamlit_app_conversion_success
+from mito_ai.path_utils import AbsoluteNotebookPath, get_absolute_notebook_dir_path, get_absolute_app_path
 
 async def generate_new_streamlit_code(notebook: List[dict]) -> str:
     """Send a query to the agent, get its response and parse the code"""
@@ -57,10 +51,9 @@ async def generate_new_streamlit_code(notebook: List[dict]) -> str:
         ]
         todo_response = await get_response_from_agent(todo_messages)
         
-        # Apply the diff to the streamlit app
-        exctracted_diff = extract_unified_diff_blocks(todo_response)
-        fixed_diff = fix_diff_headers(exctracted_diff)
-        converted_code = apply_patch_to_text(converted_code, fixed_diff)
+        # Apply the search/replace to the streamlit app
+        search_replace_pairs = extract_search_replace_blocks(todo_response)
+        converted_code = apply_search_replace(converted_code, search_replace_pairs)
                 
     return converted_code
 
@@ -80,10 +73,12 @@ async def update_existing_streamlit_code(notebook: List[dict], streamlit_app_cod
     ]
     
     agent_response = await get_response_from_agent(messages)
-    exctracted_diff = extract_unified_diff_blocks(agent_response)
-    fixed_diff = fix_diff_headers(exctracted_diff)
-    print(fixed_diff)
-    converted_code = apply_patch_to_text(streamlit_app_code, fixed_diff)
+    print(f"[Mito AI Search/Replace Tool]:\n {agent_response}")
+
+    # Apply the search/replace to the streamlit app
+    search_replace_pairs = extract_search_replace_blocks(agent_response)
+    converted_code = apply_search_replace(streamlit_app_code, search_replace_pairs)
+    print(f"[Mito AI Search/Replace Tool]\nConverted code\n: {converted_code}")
     return converted_code
 
 
@@ -100,27 +95,26 @@ async def correct_error_in_generation(error: str, streamlit_app_code: str) -> st
     ]
     agent_response = await get_response_from_agent(messages)
     
-    # Apply the diff to the streamlit app
-    exctracted_diff = extract_unified_diff_blocks(agent_response)
-    fixed_diff = fix_diff_headers(exctracted_diff)
-    streamlit_app_code = apply_patch_to_text(streamlit_app_code, fixed_diff)
+    # Apply the search/replace to the streamlit app
+    search_replace_pairs = extract_search_replace_blocks(agent_response)
+    streamlit_app_code = apply_search_replace(streamlit_app_code, search_replace_pairs)
 
     return streamlit_app_code
 
-async def streamlit_handler(notebook_path: str, edit_prompt: str = "") -> Tuple[bool, Optional[str], str]:
+async def streamlit_handler(notebook_path: AbsoluteNotebookPath, edit_prompt: str = "") -> None:
     """Handler function for streamlit code generation and validation"""
 
-    clean_directory_check(notebook_path)
-
+    # Convert to absolute path for consistent handling
     notebook_code = parse_jupyter_notebook_to_extract_required_content(notebook_path)
-    app_directory = get_app_directory(notebook_path)
+    app_directory = get_absolute_notebook_dir_path(notebook_path)
+    app_path = get_absolute_app_path(app_directory)
     
     if edit_prompt != "":
         # If the user is editing an existing streamlit app, use the update function
-        streamlit_code = get_app_code_from_file(app_directory)
+        streamlit_code = get_app_code_from_file(app_path)
         
         if streamlit_code is None:
-            return False, '', "Error updating existing streamlit app because app.py file was not found."
+            raise StreamlitConversionError("Error updating existing streamlit app because app.py file was not found.", 404)
         
         streamlit_code = await update_existing_streamlit_code(notebook_code, streamlit_code, edit_prompt)
     else:
@@ -139,17 +133,13 @@ async def streamlit_handler(notebook_path: str, edit_prompt: str = "") -> Tuple[
         if has_validation_error:
             # TODO: We can't easily get the key type here, so for the beta release
             # we are just defaulting to the mito server key since that is by far the most common.
-            log_streamlit_app_creation_retry('mito_server_key', MessageType.STREAMLIT_CONVERSION, error)
+            log_streamlit_app_validation_retry('mito_server_key', MessageType.STREAMLIT_CONVERSION, errors)
         tries+=1
 
     if has_validation_error:
-        log_streamlit_app_creation_error('mito_server_key', MessageType.STREAMLIT_CONVERSION, error, edit_prompt)
-        return False, '', "Error generating streamlit code by agent"
+        final_errors = ', '.join(errors)
+        raise StreamlitConversionError(f"Streamlit agent failed generating code after max retries. Errors: {final_errors}", 500)
     
     # Finally, update the app.py file with the new code
-    success_flag, app_path, message = create_app_file(app_directory, streamlit_code)
-    if not success_flag:
-        log_streamlit_app_creation_error('mito_server_key', MessageType.STREAMLIT_CONVERSION, message, edit_prompt)
-    
-    log_streamlit_app_creation_success('mito_server_key', MessageType.STREAMLIT_CONVERSION, edit_prompt)
-    return success_flag, app_path, message
+    create_app_file(app_path, streamlit_code)
+    log_streamlit_app_conversion_success('mito_server_key', MessageType.STREAMLIT_CONVERSION, edit_prompt)
