@@ -17,6 +17,7 @@ import { COMMAND_MITO_AI_OPEN_CHAT } from '../../commands';
 import { IChatTracker } from './token';
 import { ReadonlyPartialJSONObject } from '@lumino/coreutils';
 import { IContextManager } from '../ContextManager/ContextManagerPlugin';
+import { IStreamlitPreviewManager } from '../AppPreview/StreamlitPreviewPlugin';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { setDefaultWindowingMode, setRenameUntitledFileOnSave } from './jupyterSettingsManager';
 import { IDocumentManager } from '@jupyterlab/docmanager';
@@ -38,6 +39,7 @@ const AiChatPlugin: JupyterFrontEndPlugin<WidgetTracker> = {
     ICommandPalette,
     IRenderMimeRegistry,
     IContextManager,
+    IStreamlitPreviewManager,
     ISettingRegistry,
     IDocumentManager
   ],
@@ -50,6 +52,7 @@ const AiChatPlugin: JupyterFrontEndPlugin<WidgetTracker> = {
     palette: ICommandPalette,
     rendermime: IRenderMimeRegistry,
     contextManager: IContextManager,
+    streamlitPreviewManager: IStreamlitPreviewManager,
     settingRegistry: ISettingRegistry,
     documentManager: IDocumentManager,
     restorer: ILayoutRestorer | null,
@@ -64,6 +67,7 @@ const AiChatPlugin: JupyterFrontEndPlugin<WidgetTracker> = {
         notebookTracker,
         rendermime,
         contextManager,
+        streamlitPreviewManager,
       );
       return chatWidget;
     };
