@@ -9,6 +9,9 @@ import NucleusIcon from '../../src/icons/NucleusIcon.svg';
 import OpenIndicatorIcon from '../../src/icons/OpenIndicatorIcon.svg';
 import AppBuilderExcludeCellIcon from '../../src/icons/AppBuilderExcludeCellIcon.svg';
 import AppBuilderIncludeCellIcon from '../../src/icons/AppBuilderIncludeCellIcon.svg';
+import DeployIcon from '../../src/icons/App/DeployIcon.svg';
+import PencilIcon from '../../src/icons/PencilIcon.svg';
+import ResetCircleIcon from '../../src/icons/ResetCircleIcon.svg';
 
 export const lightBulbLabIcon = new LabIcon({
   name: 'lightbulb-icon',
@@ -34,3 +37,18 @@ export const AppBuilderIncludeCellLabIcon = new LabIcon({
   name: 'app-builder-include-cell-icon',
   svgstr: AppBuilderIncludeCellIcon
 });
+
+export const DeployLabIcon = new LabIcon({
+  name: 'deploy-icon',
+  svgstr: DeployIcon
+});
+
+export const EditLabIcon = new LabIcon({
+  name: 'edit-icon',
+  svgstr: PencilIcon
+});
+
+export const ResetCircleLabIcon = new LabIcon({
+  name: 'reset-circle-icon',
+  svgstr: ResetCircleIcon
+});
\ No newline at end of file
