@@ -6,6 +6,8 @@
 import { ChatHistoryManager, IDisplayOptimizedChatItem } from '../../Extensions/AiChat/ChatHistoryManager';
 import { IContextManager } from '../../Extensions/ContextManager/ContextManagerPlugin';
 import { INotebookTracker, NotebookPanel } from '@jupyterlab/notebook';
+import { JupyterFrontEnd } from '@jupyterlab/application';
+import { IStreamlitPreviewManager } from '../../Extensions/AppPreview/StreamlitPreviewPlugin';
 
 // Mock the notebook utilities
 jest.mock('../../utils/notebook', () => ({
@@ -27,6 +29,8 @@ describe('ChatHistoryManager', () => {
     let mockContextManager: IContextManager;
     let mockNotebookTracker: INotebookTracker;
     let mockNotebookPanel: NotebookPanel;
+    let mockApp: JupyterFrontEnd;
+    let mockStreamlitPreviewManager: IStreamlitPreviewManager;
     const mockNotebookId = '/test/notebook.ipynb';
 
     beforeEach(() => {
@@ -51,13 +55,30 @@ describe('ChatHistoryManager', () => {
 
         // Create mock notebook tracker
         mockNotebookTracker = {} as INotebookTracker;
+
+        // Create mock app
+        mockApp = {
+            shell: {
+                widgets: jest.fn(() => [])
+            }
+        } as unknown as JupyterFrontEnd;
+
+        mockStreamlitPreviewManager = {
+            hasActivePreview: jest.fn(() => false),
+            openAppPreview: jest.fn(),
+            editExistingPreview: jest.fn(),
+            closeCurrentPreview: jest.fn(),
+            getCurrentPreview: jest.fn()
+        } as IStreamlitPreviewManager;
     });
 
     describe('Constructor and Basic Functionality', () => {
         it('should initialize with empty history when no initial history is provided', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             const history = chatHistoryManager.getDisplayOptimizedHistory();
@@ -76,6 +97,8 @@ describe('ChatHistoryManager', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
                 mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager,
                 initialHistory
             );
 
@@ -100,6 +123,8 @@ describe('ChatHistoryManager', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
                 mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager,
                 initialHistory
             );
 
@@ -124,7 +149,9 @@ describe('ChatHistoryManager', () => {
         it('should add chat message from history', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             const message = { role: 'user' as const, content: 'Test message' };
@@ -140,7 +167,9 @@ describe('ChatHistoryManager', () => {
         it('should add AI message from response', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             chatHistoryManager.addAIMessageFromResponse('AI response content', 'chat');
@@ -158,7 +187,9 @@ describe('ChatHistoryManager', () => {
         it('should handle null message content gracefully', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             chatHistoryManager.addAIMessageFromResponse(null, 'chat');
@@ -170,7 +201,9 @@ describe('ChatHistoryManager', () => {
         it('should drop messages starting at specified index', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             // Add some messages
@@ -198,6 +231,8 @@ describe('ChatHistoryManager', () => {
             const originalManager = new ChatHistoryManager(
                 mockContextManager,
                 mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager,
                 initialHistory
             );
 
@@ -212,7 +247,7 @@ describe('ChatHistoryManager', () => {
 
     describe('High-Level Chat Workflows', () => {
         it('should add chat input message with metadata', async () => {
-            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
+            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker, mockApp, mockStreamlitPreviewManager);
 
             const metadata = await manager.addChatInputMessage('Test input', 'thread-123');
 
@@ -226,7 +261,7 @@ describe('ChatHistoryManager', () => {
         });
 
         it('should add agent execution message', () => {
-            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
+            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker, mockApp, mockStreamlitPreviewManager);
 
             const metadata = manager.addAgentExecutionMessage('thread-123', mockNotebookPanel, 'Execute this');
 
@@ -236,7 +271,7 @@ describe('ChatHistoryManager', () => {
         });
 
         it('should add smart debug message', () => {
-            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
+            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker, mockApp, mockStreamlitPreviewManager);
 
             const metadata = manager.addSmartDebugMessage('thread-123', 'Error message');
 
@@ -245,7 +280,7 @@ describe('ChatHistoryManager', () => {
         });
 
         it('should add agent smart debug message', () => {
-            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
+            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker, mockApp, mockStreamlitPreviewManager);
 
             const metadata = manager.addAgentSmartDebugMessage('thread-123', 'Agent error', mockNotebookPanel);
 
@@ -254,7 +289,7 @@ describe('ChatHistoryManager', () => {
         });
 
         it('should add explain code message', () => {
-            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker);
+            const manager = new ChatHistoryManager(mockContextManager, mockNotebookTracker, mockApp, mockStreamlitPreviewManager);
 
             const metadata = manager.addExplainCodeMessage('thread-123');
 
@@ -292,6 +327,8 @@ describe('ChatHistoryManager', () => {
             const originalManager = new ChatHistoryManager(
                 mockContextManager,
                 mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager,
                 initialHistory
             );
 
@@ -318,7 +355,9 @@ describe('ChatHistoryManager', () => {
         it('should correctly deduplicate assumptions across multiple agent responses', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             // Add first agent response with assumptions
@@ -356,7 +395,9 @@ describe('ChatHistoryManager', () => {
         it('should handle agent responses without assumptions correctly', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             // Add first response with assumptions
@@ -394,7 +435,9 @@ describe('ChatHistoryManager', () => {
         it('should handle empty assumptions array correctly', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             // Add first response with assumptions
@@ -432,7 +475,9 @@ describe('ChatHistoryManager', () => {
         it('should handle empty string assumptions', () => {
             const chatHistoryManager = new ChatHistoryManager(
                 mockContextManager,
-                mockNotebookTracker
+                mockNotebookTracker,
+                mockApp,
+                mockStreamlitPreviewManager
             );
 
             // Add first response with assumptions
